Encoder - LatentLego

Skip to content

# Encoder

### `latent.modules.encoder.Encoder`

Encoder base class. This model compresses input data in a latent space with `latent_dim` dimensions by through passing it through a `DenseStack`.

#### `__init__(self, latent_dim=50, name='encoder', initializer='glorot_normal', **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`latent_dim` | `int` | Integer indicating the number of dimensions in the latent space. | `50`
`name` | `str` | String indicating the name of the model. | `'encoder'`
`initializer` | `Union[str, Callable]` | Initializer for the kernel weights matrix (see `keras.initializers`) | `'glorot_normal'`
`**kwargs` | `` | Other arguments passed on to `DenseStack` | `{}`